Acknowledgments — BuildingsPy documentation

### Navigation

- index
- modules |
- next |
- previous |
- Home > BuildingsPy

# Acknowledgments

This research was supported by
  - by the Assistant Secretary for Energy Efficiency and Renewable Energy, Office of Building Technologies of the U.S. Department of Energy, under contract No. DE-AC02-05CH11231, and
  - by the California Energy Commission, Public Interest Energy Research Program, Buildings End Use Energy Efficiency Program, award number 500-10-052.

We thank Joerg Raedler for the contribution of the `dymat` module that is used to parse the Dymola output files.

### Navigation

- index
- modules |
- next |
- previous |
- Home > BuildingsPy